==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_time_zones_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTimeZonesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'time_zone_name': 'str'
    }

    attribute_map = {
        'time_zone_name': 'time_zone_name'
    }

    def __init__(self, time_zone_name=None):
        """ListTimeZonesRequest

        The model defined in huaweicloud sdk

        :param time_zone_name: 按照时区name过滤
        :type time_zone_name: str
        """
        
        

        self._time_zone_name = None
        self.discriminator = None

        if time_zone_name is not None:
            self.time_zone_name = time_zone_name

    @property
    def time_zone_name(self):
        """Gets the time_zone_name of this ListTimeZonesRequest.

        按照时区name过滤

        :return: The time_zone_name of this ListTimeZonesRequest.
        :rtype: str
        """
        return self._time_zone_name

    @time_zone_name.setter
    def time_zone_name(self, time_zone_name):
        """Sets the time_zone_name of this ListTimeZonesRequest.

        按照时区name过滤

        :param time_zone_name: The time_zone_name of this ListTimeZonesRequest.
        :type time_zone_name: str
        """
        self._time_zone_name = time_zone_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTimeZonesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_time_zones_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTimeZonesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'time_zone_name': 'str'
    }

    attribute_map = {
        'time_zone_name': 'time_zone_name'
    }

    def __init__(self, time_zone_name=None):
        r"""ListTimeZonesRequest

        The model defined in huaweicloud sdk

        :param time_zone_name: 按照时区name过滤
        :type time_zone_name: str
        """
        
        

        self._time_zone_name = None
        self.discriminator = None

        if time_zone_name is not None:
            self.time_zone_name = time_zone_name

    @property
    def time_zone_name(self):
        r"""Gets the time_zone_name of this ListTimeZonesRequest.

        按照时区name过滤

        :return: The time_zone_name of this ListTimeZonesRequest.
        :rtype: str
        """
        return self._time_zone_name

    @time_zone_name.setter
    def time_zone_name(self, time_zone_name):
        r"""Sets the time_zone_name of this ListTimeZonesRequest.

        按照时区name过滤

        :param time_zone_name: The time_zone_name of this ListTimeZonesRequest.
        :type time_zone_name: str
        """
        self._time_zone_name = time_zone_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTimeZonesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
